@@ -14,6 +14,7 @@ from gi.repository import Gtk, Gdk, GLib, Pango, GObject, WebKit2
 
 from eolie.label_indicator import LabelIndicator
 from eolie.define import App, ArtSize
+from eolie.utils import resize_favicon
 from eolie.logger import Logger
 
 
@@ -192,7 +193,11 @@ class SitesManagerChild(Gtk.ListBoxRow):
         if view not in self.__views:
             self.__views.append(view)
             view.webview.connect("shown", self.__on_webview_shown)
-            view.webview.connect("favicon-changed",
+            view.webview.connect("load-changed",
+                                 self.__on_webview_load_changed)
+            view.webview.connect("notify::is-playing-audio",
+                                 self.__on_webview_notify_is_playing_audio)
+            view.webview.connect("notify::favicon",
                                  self.__on_webview_favicon_changed)
             self.update_label()
             self.__indicator_label.update_count(True)
@@ -214,6 +219,9 @@ class SitesManagerChild(Gtk.ListBoxRow):
             self.__views.remove(view)
             view.webview.disconnect_by_func(self.__on_webview_shown)
             view.webview.disconnect_by_func(self.__on_webview_favicon_changed)
+            view.webview.disconnect_by_func(self.__on_webview_load_changed)
+            view.webview.disconnect_by_func(
+                                    self.__on_webview_notify_is_playing_audio)
             self.update_label()
             self.__indicator_label.update_count(False)
             if not view.webview.shown:
@@ -348,21 +356,21 @@ class SitesManagerChild(Gtk.ListBoxRow):
                 return True
             elif event.button == 3:
                 from eolie.menu_sites import SitesMenu
-                from eolie.menu_profiles import ProfilesMenu
+                # from eolie.menu_profiles import ProfilesMenu
                 from eolie.menu_move_to import MoveToMenu
                 sites_menu = SitesMenu(self.__views, self.__window)
                 sites_menu.show()
-                webview = self.__views[0].webview
-                profiles_menu = ProfilesMenu(webview, self.__window)
-                profiles_menu.show()
+                # webview = self.__views[0].webview
+                # profiles_menu = ProfilesMenu(webview, self.__window)
+                # profiles_menu.show()
                 moveto_menu = MoveToMenu(self.__views, self.__window)
                 moveto_menu.show()
                 popover = Gtk.PopoverMenu.new()
                 popover.add(sites_menu)
-                popover.add(profiles_menu)
+                # popover.add(profiles_menu)
                 popover.add(moveto_menu)
-                popover.child_set_property(profiles_menu,
-                                           "submenu", "profiles")
+                # popover.child_set_property(profiles_menu,
+                #                           "submenu", "profiles")
                 popover.child_set_property(moveto_menu,
                                            "submenu", "moveto")
                 popover.set_relative_to(eventbox)
@@ -403,34 +411,38 @@ class SitesManagerChild(Gtk.ListBoxRow):
         elif hasattr(widget, "forall"):
             GLib.idle_add(widget.forall, self.__update_popover_internals)
 
-    def __on_webview_favicon_changed(self, webview, surface=None):
+    def __on_webview_notify_is_playing_audio(self, webview, playing):
+        """
+            Update favicon
+            @param webview as WebView
+            @param playing as bool
+        """
+        self.__on_webview_favicon_changed(webview)
+
+    def __on_webview_favicon_changed(self, webview, *ignore):
         """
             Set favicon
             @param webview as WebView
-            @param surface as cairo.Surface
         """
-        if self.get_style_context().has_class("item-selected") and\
-                len(self.__views) > 1 and\
-                webview.view != self.__window.container.current:
+        if webview.current_event == WebKit2.LoadEvent.STARTED:
             return
 
-        if not webview.ephemeral:
-            if surface is not None:
-                self.__image.set_from_surface(surface)
-                return
-            favicon_path = App().art.get_favicon_path(webview.uri)
-            if favicon_path is not None:
-                self.__image.set_from_file(favicon_path)
-                return
+        if webview.is_playing_audio():
+            self.__image.set_from_icon_name("audio-speakers-symbolic",
+                                            Gtk.IconSize.INVALID)
+            return
 
         artwork = App().art.get_icon_theme_artwork(webview.uri,
                                                    webview.ephemeral)
         if artwork is not None:
-            self.__image.set_from_icon_name(artwork,
-                                            Gtk.IconSize.INVALID)
+            self.__image.set_from_icon_name(artwork, Gtk.IconSize.INVALID)
         else:
-            self.__image.set_from_icon_name("applications-internet",
-                                            Gtk.IconSize.INVALID)
+            surface = webview.get_favicon()
+            if surface is not None:
+                self.__image.set_from_surface(resize_favicon(surface))
+            else:
+                self.__image.set_from_icon_name("applications-internet",
+                                                Gtk.IconSize.INVALID)
 
     def __on_query_tooltip(self, widget, x, y, keyboard, tooltip):
         """
@@ -533,3 +545,15 @@ class SitesManagerChild(Gtk.ListBoxRow):
         """
         self.__indicator_label.mark_shown(webview)
         self.__on_webview_favicon_changed(webview)
+
+    def __on_webview_load_changed(self, webview, event):
+        """
+            Update widget content
+            @param webview as WebView
+            @param event as WebKit2.LoadEvent
+        """
+        if event == WebKit2.LoadEvent.STARTED:
+            self.__image.set_from_icon_name("content-loading-symbolic",
+                                            Gtk.IconSize.INVALID)
+        elif event == WebKit2.LoadEvent.FINISHED:
+            self.__on_webview_favicon_changed(webview)
