@@ -15,7 +15,7 @@ from gi.repository import GLib, Gtk, Gio, WebKit2, Gdk
 from urllib.parse import urlparse
 from time import time
 
-from eolie.define import App, ADBLOCK_JS, LoadingType, EOLIE_DATA_PATH
+from eolie.define import App, LoadingType, EOLIE_DATA_PATH
 from eolie.define import COOKIES_PATH
 from eolie.utils import get_ftp_cmd
 from eolie.logger import Logger
@@ -47,10 +47,11 @@ class WebViewNavigation:
                      self.__on_insecure_content_detected)
         self.connect("run-as-modal", self.__on_run_as_modal)
         self.connect("permission_request", self.__on_permission_request)
-        self.connect("notify::favicon", self.__on_notify_favicon)
         self.connect("notify::title", self.__on_title_changed)
         self.connect("notify::uri", self.__on_uri_changed)
 
+        self.__switch_profile(None)
+
     def load_uri(self, uri):
         """
             Load uri
@@ -103,7 +104,7 @@ class WebViewNavigation:
         parsed = urlparse(uri)
         http_scheme = parsed.scheme in ["http", "https"]
         App().history.set_page_state(uri)
-        self.__switch_profile(uri)
+        # self.__switch_profile(uri)
         self.__update_bookmark_metadata(uri)
         self.content_manager.remove_all_style_sheets()
         # Can't find a way to block content for ephemeral views
@@ -170,24 +171,7 @@ class WebViewNavigation:
                     return
         elif event == WebKit2.LoadEvent.COMMITTED:
             self.emit("uri-changed", self.uri)
-            http_scheme = parsed.scheme in ["http", "https"]
             self.update_zoom_level()
-            # Setup eolie internal adblocker
-            if App().settings.get_value("adblock") and\
-                    http_scheme:
-                exception = App().adblock_exceptions.find_parsed(parsed)
-                if not exception:
-                    noext = ".".join(parsed.netloc.split(".")[:-1])
-                    javascripts = ["adblock_%s.js" % parsed.netloc,
-                                   "adblock_%s.js" % noext]
-                    for javascript in javascripts:
-                        f = Gio.File.new_for_path("%s/%s" % (ADBLOCK_JS,
-                                                             javascript))
-                        if f.query_exists():
-                            (status, content, tag) = f.load_contents(None)
-                            js = content.decode("utf-8")
-                            self.run_javascript(js, None, None)
-                            break
         elif event == WebKit2.LoadEvent.FINISHED:
             self.update_spell_checking(self.uri)
             self.run_javascript_from_gresource(
@@ -239,7 +223,8 @@ class WebViewNavigation:
         """
         if self.ephemeral or self.__related_view is not None:
             return
-        profile = App().websettings.get_profile(uri)
+        # profile = App().websettings.get_profile(uri)
+        profile = "default"
         if self.__profile != profile:
             self.__profile = profile
             cookie_manager = self.get_context().get_cookie_manager()
@@ -281,13 +266,12 @@ class WebViewNavigation:
             @param webview as WebKit2.WebView
             @param param as GObject.ParamSpec
         """
-        # Js update, force favicon caching for current uri
+        # Js update
         if not self.is_loading():
             uri = webview.get_property(param.name)
             # JS bookmark (Bookmarklet)
             if not uri.startswith("javascript:") and not self.error:
                 self.emit("uri-changed", uri)
-                self.set_current_favicon()
 
     def __on_title_changed(self, webview, param):
         """
@@ -299,14 +283,6 @@ class WebViewNavigation:
         if title:
             self.emit("title-changed", title)
 
-    def __on_notify_favicon(self, webview, favicon):
-        """
-            Set favicon
-            @param webview as WebView
-            @param favicon as GObject.ParamSpec
-        """
-        self.set_favicon()
-
     def __on_decide_policy(self, webview, decision, decision_type):
         """
             Navigation policy
@@ -383,18 +359,18 @@ class WebViewNavigation:
                 return False
         elif mouse_button == 1:
             if decision_type == WebKit2.PolicyDecisionType.NEW_WINDOW_ACTION:
-                if self._window.modifiers & Gdk.ModifierType.SHIFT_MASK:
+                if self._window.modifiers == Gdk.KEY_Shift_L:
                     loading_type = LoadingType.POPOVER
                 else:
                     loading_type = LoadingType.FOREGROUND
                 self.new_page(navigation_uri, loading_type)
                 decision.ignore()
                 return True
-            elif self._window.modifiers & Gdk.ModifierType.CONTROL_MASK:
+            elif self._window.modifiers == Gdk.KEY_Control_L:
                 self.new_page(navigation_uri, LoadingType.BACKGROUND)
                 decision.ignore()
                 return True
-            elif self._window.modifiers & Gdk.ModifierType.SHIFT_MASK:
+            elif self._window.modifiers == Gdk.KEY_Shift_L:
                 self.new_page(navigation_uri, LoadingType.POPOVER)
                 decision.ignore()
                 return True
